==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Izbor ene ali več naprav</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Preklopi na okno</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Preklopi na celozaslonski način</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Izbor ene ali več naprav</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Ni najdenega upravljalnika datotek.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Program za urejanje datotek je treba namestiti.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Opozorilo</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Snemanje ni začeto, ker ni dovolj prostora na disku.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Dosežena je omejitev prostora na disku.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Omejitev prostora na disku</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Snemanje je zaustavljeno, ker ni dovolj prostora na disku.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Celozaslonski način</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Ni najdenega upravljalnika datotek.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Program za urejanje datotek je treba namestiti.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Izvorna koda</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Spletna stran</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Prevodi</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doniraj</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Izbor ene ali več naprav</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Območje</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Začni</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Premor</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Nadaljuj</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Končaj</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Povečava</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Začni</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Premor</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Nadaljuj</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Končaj</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Pogovorno okno</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Zrcali vodoravno</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Zrcali navpično</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Obrni</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Sivo</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Črnobelo</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Odstrani okvir okna</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Nastavitve kamere</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Območje</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Ponastavi</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Povečava</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Odštevalnik</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Velikost videa:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Prostor na disku:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Čas snemanja</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Zvok</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Sličice</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Video kodek</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Zapis</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Zvokovni kodek</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kakovost</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Ne snemaj kazalke miške</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Ura</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuta</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Začni časomer</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Zaustavi snemanje po</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>H</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>M</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>S</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Pot do videa</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Omejitev prostora na disku</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Pokaži v sistemski vrstici</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Čas čakanja pred začetkom snemanja</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Poišči posodobitve</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Na voljo</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Ni na voljo</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Začni</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Premor</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Nadaljuj</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Predvajaj</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Obrni</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Sivo</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Pošlji poročilo</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Predvajaj zadnji posnetek</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Odpri mapo</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Pomanjšaj, ko se snemanje začne</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Začni pomanjšano</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Zrcali vodoravno</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Zrcali navpično</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Črnobelo</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Odstrani okvir okna</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doniraj</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Ponastavi nastavitve ob naslednjem zagonu</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Avtorske pravice in dovoljenja slik</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Zaslonski posnetek</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Predvajalnik</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Dnevnik</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Avtorske pravice in dovoljenja slik</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Predvajaj</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Premor</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Odpri datoteko</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celozaslonski način</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Predhodna sličica</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Naslednja sličica</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Utišaj</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Premakni meni</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.3.0.orig.tar.gz: vokoscreenNG-3.3.0/src/language/sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Izbor ene ali več naprav</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Preklopi na okno</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Preklopi na celozaslonski način</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Izbor ene ali več naprav</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Ni najdenega upravljalnika datotek.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Program za urejanje datotek je treba namestiti.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Opozorilo</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Snemanje ni začeto, ker ni dovolj prostora na disku.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Dosežena je omejitev prostora na disku.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Omejitev prostora na disku</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Snemanje je zaustavljeno, ker ni dovolj prostora na disku.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Celozaslonski način</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Ni najdenega upravljalnika datotek.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Program za urejanje datotek je treba namestiti.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Izvorna koda</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Spletna stran</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Prevodi</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doniraj</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Izbor ene ali več naprav</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Območje</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Območje</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Začni</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Premor</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Nadaljuj</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Končaj</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Povečava</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Začni</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Premor</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Nadaljuj</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Končaj</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Povečava</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Pogovorno okno</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Zrcali vodoravno</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Zrcali navpično</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Obrni</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Sivo</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Črnobelo</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Odstrani okvir okna</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Nastavitve kamere</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Območje</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Ponastavi</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Povečava</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Odštevalnik</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Velikost videa:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Prostor na disku:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Čas snemanja</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Zvok</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Sličice</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Video kodek</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Zapis</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Zvokovni kodek</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kakovost</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Ne snemaj kazalke miške</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Ura</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuta</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Začni časomer</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Zaustavi snemanje po</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>H</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>M</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>S</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Pot do videa</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Omejitev prostora na disku</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Pokaži v sistemski vrstici</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Čas čakanja pred začetkom snemanja</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Poišči posodobitve</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Na voljo</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Ni na voljo</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Začni</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Premor</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Nadaljuj</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Predvajaj</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Obrni</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Sivo</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Pošlji poročilo</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Predvajaj zadnji posnetek</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Odpri mapo</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Pomanjšaj, ko se snemanje začne</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Začni pomanjšano</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Zrcali vodoravno</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Zrcali navpično</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Črnobelo</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Odstrani okvir okna</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doniraj</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Ponastavi nastavitve ob naslednjem zagonu</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Avtorske pravice in dovoljenja slik</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Zaslonski posnetek</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Predvajalnik</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Dnevnik</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>License information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ON</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OFF</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Avtorske pravice in dovoljenja slik</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Predvajaj</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Premor</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Odpri datoteko</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celozaslonski način</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Predhodna sličica</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Naslednja sličica</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Utišaj</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Premakni meni</translation>
    </message>
</context>
</TS>
